@@ -74,4 +74,9 @@ from .ray_box_intersect import ray_box_intersect
 from .ray_triangle_intersect import ray_triangle_intersect
 from .catmull_rom_spline import catmull_rom_spline
 from .random_points_on_mesh import random_points_on_mesh
-from .compactly_supported_normal import compactly_supported_normal
\ No newline at end of file
+from .compactly_supported_normal import compactly_supported_normal
+from .matrix_from_function import matrix_from_function
+from .angle_defect import angle_defect
+from .angle_defect_intrinsic import angle_defect_intrinsic
+from .grid_neighbors import grid_neighbors
+from .grid_laplacian_eigenfunctions import grid_laplacian_eigenfunctions
\ No newline at end of file
